# framework-identifier
This repository is the python implementation of the repo(https://github.com/AliasIO/Wappalyzer). 
## Setup
Run:
`pip install -r requirements.txt`
## Running the script
To run the script, the following command is to be used:
`python wappalyze.py`


Install from pip

pip install wappalyze

# Usage

wappalyze.py -u google.com

# Use as a module

import wappalyzer

result wappalyzer.analyze('google.com')

print(result)